<!DOCTYPE html>
<html>
<head>
    <title>{{ title }}</title>

    {% block styles %}{% endblock %}
</head>
<body>
    <div class="wrapper">
        <header>
            {% block header %}{% endblock %}
        </header>
        <nav>

        </nav>
        <div class="content">
            {% block content %}{% endblock %}
        </div>
        <aside>
            {% block aside %}{% endblock %}
        </aside>
    </div>

    {% block scripts %}{% endblock %}
</body>
</html>
