{% extends "admin/change_list.html" %}
{% load admin_static %}

{% block extrastyle %}
{{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% static "admin/css/warthog.css" %}" />
{% endblock %}
